==> orchestra-pvm-4.2.1-sources.jar: org/ow2/orchestra/pvm/internal/jobexecutor/GetNextDueDateCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.jobexecutor;

import java.util.Date;

import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.internal.cmd.Command;
import org.ow2.orchestra.pvm.internal.job.JobImpl;
import org.ow2.orchestra.pvm.internal.log.Log;

/**
 * @author Tom Baeyens
 */
public class GetNextDueDateCmd implements Command<Date> {

  private static final long serialVersionUID = 1L;

  private static final Log LOG = Log.getLog(GetNextDueDateCmd.class.getName());

  public GetNextDueDateCmd() {
  }

  public Date execute(final Environment environment) throws Exception {
    Date nextDueDate = null;
    GetNextDueDateCmd.LOG.debug("getting next due date...");
    final JobDbSession jobDbSession = environment.get(JobDbSession.class);
    final JobImpl< ? > job = jobDbSession.findFirstDueJob();
    if (job != null) {
      nextDueDate = job.getDueDate();
    }
    GetNextDueDateCmd.LOG.debug("next due date is " + nextDueDate);
    return nextDueDate;
  }

}

==> orchestra-pvm-4.4.1-sources.jar: org/ow2/orchestra/pvm/internal/jobexecutor/GetNextDueDateCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.jobexecutor;

import java.util.Date;

import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.internal.cmd.Command;
import org.ow2.orchestra.pvm.internal.job.JobImpl;
import org.ow2.orchestra.pvm.internal.log.Log;

/**
 * @author Tom Baeyens
 */
public class GetNextDueDateCmd implements Command<Date> {

  private static final long serialVersionUID = 1L;

  private static final Log LOG = Log.getLog(GetNextDueDateCmd.class.getName());

  public GetNextDueDateCmd() {
  }

  public Date execute(final Environment environment) {
    Date nextDueDate = null;
    GetNextDueDateCmd.LOG.debug("getting next due date...");
    final JobDbSession jobDbSession = environment.get(JobDbSession.class);
    final JobImpl< ? > job = jobDbSession.findFirstDueJob();
    if (job != null) {
      nextDueDate = job.getDueDate();
    }
    GetNextDueDateCmd.LOG.debug("next due date is " + nextDueDate);
    return nextDueDate;
  }

}
